/**
 * Copyright (c) 2025 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#include "console/console.h"
#include "client/client.h"
#include "server/server.h"
#include "util/string.h"
#include "assert/assert.h"

bool_t exitRequested = false;

void cmdExit(const consolecmdexec_t *exec) {
  exitRequested = true;
}

int main(void) {
  assertInit();
  consoleInit();
  clientInit();
  serverInit();

  consoleRegCmd("exit", cmdExit);

  InitWindow(1280, 720, DUSK_NAME);

  while(!WindowShouldClose()) {
    consoleUpdate();

    BeginDrawing();
    ClearBackground(RAYWHITE);

    consoleDraw();

    EndDrawing();

    if(exitRequested) break;
  }

  CloseWindow();
  
  serverDispose();
  clientDispose();
  
  return EXIT_SUCCESS;
}